(#1) CHEP Purpose and Guidelines — Cheetah3 - The Python-Powered Template Engine

# (#1) CHEP Purpose and Guidelines

CHEP: | 1
Title: | CHEP Purpose and Guidelines
Version: | 1
Author: | R Tyler Ballance <tyler at slide.com>
Status: | Active
Type: | Process
Content-Type: | text/x-rst
Created: | 07-Jun-2009

## Abstract

One can consider the basis for all CHEP documents to be modeled after PEP #1, for this reason you should refer to PEP #1 for the true CHEP “purpose and guidelines” instead of them being enumerated here (and duplicated).

## Copyright

This document has been placed in the public domain.